.. molecular-simulations documentation master file, created by
   sphinx-quickstart on Tue Jul 29 18:40:00 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

molecular-simulations documentation
===================================

**molecular simulations** is a library of helper functions and classes for building and deploying molecular dynamics simulations in OpenMM. Additionally a number of analysis frameworks are included for processing both MD data as well as ML-folded proteins.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

    usage
    api
